@@ -65,8 +65,7 @@ size_t odr_total(ODR o)
 Odr_oct *odr_create_Odr_oct(ODR o, const char *buf, int sz)
 {
     Odr_oct *p = (Odr_oct *) odr_malloc(o, sizeof(Odr_oct));
-    p->buf = (char *) odr_malloc(o, sz);
-    memcpy(p->buf, buf, sz);
+    p->buf = odr_strdupn(o, buf, sz);
     p->len = sz;
     return p;
 }
