@@ -121,9 +121,7 @@ Z_SortKeySpecList *yaz_sort_spec(ODR out, const char *arg)
                     odr_malloc(out, sizeof(Odr_oct));
                 i++;
                 sks->u.missingValueData->len = strlen(sort_flags+i);
-                sks->u.missingValueData->size = sks->u.missingValueData->len;
-                sks->u.missingValueData->buf = (unsigned char*)
-                                          odr_strdup(out, sort_flags+i);
+                sks->u.missingValueData->buf = odr_strdup(out, sort_flags+i);
                 i += strlen(sort_flags+i) - 1;
                 break;
             }
